@@ -43,7 +43,12 @@ class TelegramObject(object):
         Returns:
             telegram.TelegramObject:
         """
-        raise NotImplementedError
+        if not data:
+            return None
+
+        data = data.copy()
+
+        return data
 
     def to_json(self):
         """
@@ -59,8 +64,9 @@ class TelegramObject(object):
         """
         data = dict()
 
-        for key, value in self.__dict__.items():
-            if value:
+        for key in iter(self.__dict__):
+            value = self.__dict__[key]
+            if value is not None:
                 if hasattr(value, 'to_dict'):
                     data[key] = value.to_dict()
                 else:
