@@ -18,7 +18,7 @@
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 
-"""This module contains a object that represents a Telegram User"""
+"""This module contains a object that represents a Telegram User."""
 
 from telegram import TelegramObject
 
